# Testcenter Connector

Diese Bibliothek bietet die Möglichkeit die [IQB Testcenter-API](https://github.com/iqb-berlin/testcenter) aus einem
PHP Projekt heraus anzusprechen.

## Voraussetzungen

* PHP 7.2 oder neuer
* dom Extension
* json Extension
* xmlwriter Extension

## Installation

Nutzen Sie [composer](https://getcomposer.org/) zur Installation der Library. Die Installationanleitung von Composer
finden sie auf deren [Website](https://getcomposer.org/doc/00-intro.md#installation-linux-unix-macos).
Wenn sie composer bereits installiert haben führen sie folgende Schritte aus:

Öffnen sie die Datei composer.json vom root folder und fügen sie folgende Zeilen ein:
```json
"repositories": [
    {
    "type": "vcs",
    "url": "https://git.uni-jena.de/kompetenztest.de/tba2/testcenter-connector"
    }
]
```

* gehen sie in die Kommandozeile und gehen Sie in den root Ordner Ihrer Applikation. Führen Sie das folgende Kommando aus:
```bash
composer require kompetenztestde/testcenter-connector
```

Es sollte sich jetzt im vendor Folder befinden und die Bibliothek erfolgreich installiert sein.

## Nutzung

Der empfohlene Weg zur Nutzung der Bibliothek ist die Nutzung der [TestcenterConnector](src/TestcenterConnector.php)
Klasse. Diese Klasse stellt Funktionen für typische Use Cases wie das Anlegen eines Tests, das Anlegen
einer Testgruppe und das Abrufen der Antworten zur Verfügung.

Um eine Instanz von `TestcenterConnector` zu erstellen, wird ein Testcenter-User und die Basis-URL
der Testcenter REST-API benötigt:

```php
$testcenterBaseUrl = 'http://example.org/api';
$user = new Kompetenztestde\TestcenterConnector\Models\User('super', 'user123');
$connector = new Kompetenztestde\TestcenterConnector\TestcenterConnector($user, $testcenterBaseUrl);
```

### Testgruppe anlegen

Um einen Test durchzuführen, müssen für einzelne Schulklassen Testgruppen angelegt werden. Für diesen Schritt
existiert in `TestcenterConnector` die Methode `addTestGroup(...)`, die folgendermaßen genutzt werden kann:

```php
$workspaceId = 1; # ID des Workspace in dem die Testgruppe angelegt werden soll

$groupId = 'klasse-3a';
$groupLabel = 'Klasse 3A';

$logins = [
    new Kompetenztestde\TestcenterConnector\Models\Pupil('schueler_in_1', 'passwort1'),
    [...],
    new Kompetenztestde\TestcenterConnector\Models\Teacher('lehrer_in', 'passwort2')
];

$group = new Kompetenztestde\TestcenterConnector\Models\TestGroup(
    $groupId,
    $groupLabel,
    $logins
);

$bookletId = 'vera3'; # ID des Testhefts, dass die Klasse durchführen soll (muss zuvor angelegt werden)

try {
    $connector->addTestGroup($workspaceId, $group, $bookletId);
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

Mit dieser Methode werden für alle Schüler\*innen individuelle Nutzer\*innennamen und Passwörter angelegt. Es ist
aber auch möglich ein Klassenpasswort zu verwenden und im Testcenter nur einen Usernamen, der aus dem ursprünglichen
Username und dem Klassenpasswort besteht. Dies kann z.B. für die Anmeldung über QR-Codes genutzt werden:

```php
$workspaceId = 1; # ID des Workspace in dem die Testgruppe angelegt werden soll

$groupId = 'klasse-3a';
$groupLabel = 'Klasse 3A';

$logins = [
    new Kompetenztestde\TestcenterConnector\Models\Pupil('schueler_in_1'),
    new Kompetenztestde\TestcenterConnector\Models\Pupil('schueler_in_2'),
    [...]
];

$group = new Kompetenztestde\TestcenterConnector\Models\TestGroup(
    $groupId,
    $groupLabel,
    $logins,
    'klassenpasswort'
);

$bookletId = 'vera3'; # ID des Testhefts, dass die Klasse durchführen soll (muss zuvor angelegt werden)

try {
    $connector->addTestGroup($workspaceId, $group, $bookletId);
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

Es werden dann Logins mit den Usernamen `klassenpasswort-schueler_in_1` und `klassenpasswort-schueler_in_2` erstellt.

### Workspace hinzufügen

Um einen neuen Workspace im Testcenter anzulegen kann die Methode `addWorkspace(string $name)` verwendet
werden. Sie erwartet als Parameter den Namen des neuen Workspace. Dieser muss innerhalb einer Instanz
eindeutig sein. Wenn er nicht eindeutig ist, wird eine `TestcenterConnectorException` geworfen. Die
Methode gibt die ID des neu erstellten Workspace zurück.

```php
try {
    $workspaceId = $connector->addWorkspace('new-workspace');
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

### Workspaces auflisten

Um alle Workspaces einer Testcenter Instanz aufzulisten, kann die Methode `getWorkspaces()` verwendet werden.
Diese gibt eine Liste mit den IDs und Namen der vorhandenen Workspaces zurück.

```php
try {
    $workspaces = $connector->getWorkspaces();
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

### Workspace löschen

Ein vorhandener Workspace kann mit der Methode `deleteWorkspace(int $id)` gelöscht werden.

```php
try {
    $connector->deleteWorkspace(1);
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

### Test hochladen

Um einen Test hochzuladen muss zunächst eine Testinstanz angelegt werden:

```php
$test = new Kompetenztestde\TestcenterConnector\Models\FileTest(
    'PATH_TO_BOOKLET.xml',
    [
        'PATH_TO_UNIT1.xml',
        'PATH_TO_UNIT2.xml',
        'PATH_TO_UNIT3.xml'
    ],
    [
        'PATH_TO_RESOURCE1.html',
        'PATH_TO_RESOURCE2.json'
    ]
);
```

Dieser kann anschließend mit Methode `addTest(int $workspaceId, TestInterface $test)` zu einem Workspace
hinzugefügt werden. Im Testcenter werden die hochgeladenen Dateien validiert und die Methode gibt das
Validierungsergebnis zurück.

```php
try {
    $uploadValidationResult = $connector->addTest(1, $test);
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

### Testantworten herunterladen

Zum Herunterladen der abgegebenen Antworten nach der Testdurchführung, wird die Methode
`getGroupResults(int $workspaceId, string $groupId)` verwendet. Diese erwartet als Parameter die
ID des Workspaces in dem der Test durchgeführt wurde und die ID der Testgruppe, deren Ergebnisse
abgerufen werden sollen.

```php
try {
    $results = $connector->getGroupResults(1, 'test-group-1');
} catch (\Exception $e) {
    // handle exception
    echo $e->getMessage();
}
```

### Mehrere Testcenter Instanzen ansprechen

Mit der Klasse `MultiTestcenterConnector` können mehrere Testcenter Instanzen gleichzeitig angesprochen werden. Sie
bildet einen Wrapper um `TestcenterConnector` und stellt alle Methoden von `TestcenterConnector` zur Verfügung.

Beispiel:

```php
$config1 = new TestcenterInstanceConfig('http://testcenter1/api', new User('super', 'user123', User::ADMIN_ROLE));
$config2 = new TestcenterInstanceConfig('http://testcenter2/api', new User('super', 'user123', User::ADMIN_ROLE));

$connector = new MultiTestcenterConnector([$config1, $config2]);

try {
    $result = $connector->addWorkspaceAsync('New Workspace');
} catch (\Exception $e) {
    // handle exception
}
```

Als Rückgabewerte erhält man ein assoziatives Array mit der Base-URL der jeweiligen Testcenter Instanz als Key und
deren Antwort als Wert.

Um mehrere Testcenter Instanzen parallel anzusprechen, müssen die asynchronen Varianten der Methoden verwendet werden.
Bei den synchronen Methoden werden die Testcenter Instanzen sequentiell nacheinander angesprochen.

## License

Guzzle ist unter der MIT-Lizenz (MIT) verfügbar. Weitere Informationen finden Sie in der [License File](LICENSE)


## Support

Für Unterstützung wenden Sie sich bitte an: it@inio.de
