<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class File
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $name;

    /**
     * @var int
     */
    private $size;

    /**
     * @var int
     */
    private $modificationTime;

    /**
     * @var FileInfo
     */
    private $info;

    /**
     * @var string
     */
    private $type;

    /**
     * @param object $data
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->name = $data->name;
        $this->size = $data->size;
        $this->modificationTime = $data->modificationTime;
        $this->type = $data->type;
        $this->info = new FileInfo($data->info);
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return int
     */
    public function getSize(): int
    {
        return $this->size;
    }

    /**
     * @return int
     */
    public function getModificationTime(): int
    {
        return $this->modificationTime;
    }

    /**
     * @return string
     */
    public function getType(): string
    {
        return $this->type;
    }

    /**
     * @return FileInfo
     */
    public function getInfo(): FileInfo
    {
        return $this->info;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('name', 'string', true),
            new FieldValidationConstraint('size', 'int', true),
            new FieldValidationConstraint('modificationTime', 'int', true),
            new FieldValidationConstraint('type', 'string', true),
            new FieldValidationConstraint('info', 'object', true),
        ];
    }
}
