<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class FileDeletionResponse
{
    use ValidationTrait;

    /**
     * @var string[]|null
     */
    private $deleted;

    /**
     * @var string[]|null
     */
    private $didNotExist;

    /**
     * @var string[]|null
     */
    private $notAllowed;

    /**
     * @var string[]|null
     */
    private $wasUsed;

    /**
     * @param object $data json api response object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);

        $this->deleted = $data->deleted ?? null;
        $this->didNotExist = $data->did_not_exist ?? null;
        $this->notAllowed = $data->not_allowed ?? null;
        $this->wasUsed = $data->was_used ?? null;
    }

    /**
     * @return string[]
     */
    public function getDeleted(): array
    {
        return $this->deleted;
    }

    /**
     * @return string[]
     */
    public function getDidNotExist(): array
    {
        return $this->didNotExist;
    }

    /**
     * @return string[]
     */
    public function getNotAllowed(): array
    {
        return $this->notAllowed;
    }

    /**
     * @return string[]
     */
    public function getWasUsed(): array
    {
        return $this->wasUsed;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('deleted', 'array', false),
            new FieldValidationConstraint('did_not_exist', 'array', false),
            new FieldValidationConstraint('not_allowed', 'array', false),
            new FieldValidationConstraint('was_used', 'array', false)
        ];
    }
}
