<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class FileGetResponse
{
    use ValidationTrait;

    /**
     * @var File[]
     */
    private $booklet;

    /**
     * @var File[]
     */
    private $sysCheck;

    /**
     * @var File[]
     */
    private $testtakers;

    /**
     * @var File[]
     */
    private $unit;

    /**
     * @var File[]
     */
    private $resource;

    /**
     * @param object $data
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        $this->booklet = isset($data->Booklet) ? array_map(function ($bookletData) {
            return new File($bookletData);
        }, $data->Booklet) : [];

        $this->sysCheck = isset($data->SysCheck) ? array_map(function ($sysCheckData) {
            return new File($sysCheckData);
        }, $data->SysCheck) : [];

        $this->testtakers = isset($data->Testtakers) ? array_map(function ($testtakerData) {
            return new File($testtakerData);
        }, $data->Testtakers) : [];

        $this->unit = isset($data->Unit) ? array_map(function ($unitData) {
            return new File($unitData);
        }, $data->Unit) : [];

        $this->resource = isset($data->Resource) ? array_map(function ($resourceData) {
            return new File($resourceData);
        }, $data->Resource) : [];
    }


    /**
     * @return File[]
     */
    public function getBooklets(): array
    {
        return $this->booklet;
    }

    /**
     * @return File[]
     */
    public function getSysChecks(): array
    {
        return $this->sysCheck;
    }

    /**
     * @return File[]
     */
    public function getTesttakers(): array
    {
        return $this->testtakers;
    }

    /**
     * @return File[]
     */
    public function getUnits(): array
    {
        return $this->unit;
    }

    /**
     * @return File[]
     */
    public function getResources(): array
    {
        return $this->resource;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('Booklet', 'array'),
            new FieldValidationConstraint('SysCheck', 'array'),
            new FieldValidationConstraint('Testtakers', 'array'),
            new FieldValidationConstraint('Unit', 'array'),
            new FieldValidationConstraint('Resource', 'array'),
        ];
    }
}
