<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

class FileUploadResponse
{
    /**
     * @var FileValidationResult[]
     */
    private $fileValidationResults;

    /**
     * @param FileValidationResult[] $fileValidationResults
     */
    public function __construct(array $fileValidationResults)
    {
        $this->fileValidationResults = $fileValidationResults;
    }

    /**
     * @return FileValidationResult[]
     */
    public function getFileValidationResults(): array
    {
        return $this->fileValidationResults;
    }

    /**
     * Check if any uploaded file produced warnings
     *
     * @return bool true if any uploaded file has warnings, else false
     */
    public function hasWarnings(): bool
    {
        $warningFiles = array_filter($this->fileValidationResults, function ($result) {
            return count($result->getWarnings()) > 0;
        });
        return count($warningFiles) > 0;
    }

    /**
     * Check if any uploaded file produced errors
     *
     * @return bool true if any uploaded file has errors, else false
     */
    public function hasErrors(): bool
    {
        $errorFiles = array_filter($this->fileValidationResults, function ($result) {
            return count($result->getErrors()) > 0;
        });
        return count($errorFiles) > 0;
    }

    /**
     * Get all errors of the response
     *
     * @return array associative array with filenames as keys and array of errors as values
     */
    public function getErrors(): array
    {
        $errorFiles = array_filter($this->fileValidationResults, function ($result) {
            return count($result->getErrors()) > 0;
        });
        $errors = [];

        foreach ($errorFiles as $errorFile) {
            $errors[$errorFile->getFilename()] = $errorFile->getErrors();
        }

        return $errors;
    }
}
