<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class ItemResponse
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $id;

    /**
     * @var string
     */
    private $content;

    /**
     * @var int
     */
    private $ts;

    /**
     * @var string
     */
    private $responseType;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->id = $data->id;
        $this->content = $data->content;
        $this->ts = $data->ts;
        $this->responseType = $data->responseType;
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getContent(): string
    {
        return $this->content;
    }

    /**
     * @return  int
     */
    public function getTs(): int
    {
        return $this->ts;
    }

    /**
     * @return string
     */
    public function getResponseType(): string
    {
        return $this->responseType;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('id', 'string', true),
            new FieldValidationConstraint('content', 'string', true),
            new FieldValidationConstraint('ts', 'integer', true),
            new FieldValidationConstraint('responseType', 'string', true)
        ];
    }
}
