<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class LogEntry
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $groupName;

    /**
     * @var string
     */
    private $loginName;

    /**
     * @var string|null
     */
    private $code;

    /**
     * @var string|null
     */
    private $bookletName;

    /**
     * @var string|null
     */
    private $unitName;

    /**
     * @var int|null
     */
    private $timestamp;

    /**
     * @var string|null
     */
    private $logEntry;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->groupName = $data->groupname;
        $this->loginName = $data->loginname;
        $this->code = $data->code ?? null;
        $this->bookletName = $data->bookletname ?? null;
        $this->unitName = $data->unitname ?? null;
        $this->timestamp = $data->timestamp;
        $this->logEntry = $data->logentry ?? null;
    }

    /**
     * @return string
     */
    public function getGroupName(): string
    {
        return $this->groupName;
    }

    /**
     * @return string
     */
    public function getLoginName(): string
    {
        return $this->loginName;
    }

    /**
     * @return string
     */
    public function getCode(): string
    {
        return $this->code;
    }

    /**
     * @return string
     */
    public function getBookletName(): string
    {
        return $this->bookletName;
    }

    /**
     * @return string
     */
    public function getUnitName(): string
    {
        return $this->unitName;
    }

    /**
     * @return int
     */
    public function getTimestamp(): int
    {
        return $this->timestamp;
    }

    /**
     * @return string
     */
    public function getLogEntry(): string
    {
        return $this->logEntry;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('groupname', 'string', true),
            new FieldValidationConstraint('loginname', 'string', true),
            new FieldValidationConstraint('code', 'string', false),
            new FieldValidationConstraint('bookletname', 'string', false),
            new FieldValidationConstraint('unitname', 'string', false),
            new FieldValidationConstraint('timestamp', 'integer', true),
            new FieldValidationConstraint('logentry', 'string', false)
        ];
    }
}
