<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use DateTime;
use Exception;
use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class Result
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $groupName;

    /**
     * @var int|null
     */
    private $bookletsStarted;

    /**
     * @var int|null
     */
    private $numUnitsMin;

    /**
     * @var int|null
     */
    private $numUnitsMax;

    /**
     * @var int|null
     */
    private $numUnitsTotal;

    /**
     * @var double|null
     */
    private $numUnitsAvg;

    /**
     * @var DateTime|null
     */
    private $lastChange;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->groupName = $data->groupName;
        $this->bookletsStarted = $data->bookletsStarted ?? null;
        $this->numUnitsMin = $data->numUnitsMin ?? null;
        $this->numUnitsMax = $data->numUnitsMax ?? null;
        $this->numUnitsTotal = $data->numUnitsTotal ?? null;
        $this->numUnitsAvg = $data->numUnitsAvg ?? null;

        $date = isset($data->lastChange) ? date(DATE_ATOM, $data->lastChange) : null;

        try {
            $date = new DateTime($date);
        } catch (Exception $e) {
            throw new TestcenterConnectorException('Expected "lastChange" to be a valid date time value');
        }

        $this->lastChange = $date;
    }

    /**
     * @return string
     */
    public function getGroupName(): string
    {
        return $this->groupName;
    }

    /**
     * @return int
     */
    public function getBookletsStarted(): int
    {
        return $this->bookletsStarted;
    }

    /**
     * @return int
     */
    public function getNumUnitsMin(): int
    {
        return $this->numUnitsMin;
    }

    /**
     * @return int
     */
    public function getNumUnitsMax(): int
    {
        return $this->numUnitsMax;
    }

    /**
     * @return int
     */
    public function getNumUnitsTotal(): int
    {
        return $this->numUnitsTotal;
    }

    /**
     * @return float
     */
    public function getNumUnitsAvg(): float
    {
        return $this->numUnitsAvg;
    }

    /**
     * @return DateTime
     */
    public function getLastChange(): DateTime
    {
        return $this->lastChange;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('groupName', 'string', true),
            new FieldValidationConstraint('bookletsStarted', 'integer', false),
            new FieldValidationConstraint('numUnitsMin', 'integer', false),
            new FieldValidationConstraint('numUnitsMax', 'integer', false),
            new FieldValidationConstraint('numUnitsTotal', 'integer', false),
            new FieldValidationConstraint('numUnitsAvg', 'double', false),
            new FieldValidationConstraint('lastChange', 'integer', false)
        ];
    }
}
