<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class SessionResponse
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $token;

    /**
     * @var string
     */
    private $displayName;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->token = $data->token;
        $this->displayName = $data->displayName;
    }

    /**
     * @return string $token
     */
    public function getToken(): string
    {
        return $this->token;
    }

    /**
     * @return string $displayName
     */
    public function getDisplayName(): string
    {
        return $this->displayName;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('token', 'string', true),
            new FieldValidationConstraint('displayName', 'string', true)
        ];
    }
}
