<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class StartSessionResponse
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $token;

    /**
     * @var string
     */
    private $displayName;

    /**
     * @var int|null
     */
    private $id = null;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->token = $data->token;
        $this->displayName = $data->displayName;

        if (isset($data->id)) {
            $this->id = $data->id;
        }
    }

    /**
     * @return string
     */
    public function getToken(): string
    {
        return $this->token;
    }

    /**
     * @return string
     */
    public function getDisplayName(): string
    {
        return $this->displayName;
    }

    /**
     * @return int|null
     */
    public function getId(): ?int
    {
        return $this->id;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('token', 'string', true),
            new FieldValidationConstraint('displayName', 'string', true),
            new FieldValidationConstraint('id', 'int', false)
        ];
    }
}
