<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class SysCheckItem
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $id;

    /**
     * @var string
     */
    private $type;

    /**
     * @var string
     */
    private $label;

    /**
     * @var mixed
     */
    private $value;

    /**
     * @var bool
     */
    private $warning;

    /**
     * @param object $data
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->id = $data->id;
        $this->type = $data->type;
        $this->label = $data->label;
        $this->value = $data->value;
        $this->warning = $data->warning;
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getType(): string
    {
        return $this->type;
    }

    /**
     * @return string
     */
    public function getLabel(): string
    {
        return $this->label;
    }

    /**
     * @return mixed
     */
    public function getValue()
    {
        return $this->value;
    }

    /**
     * @return bool
     */
    public function isWarning(): bool
    {
        return $this->warning;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('id', 'string', true),
            new FieldValidationConstraint('type', 'string', true),
            new FieldValidationConstraint('label', 'string', true),
            new FieldValidationConstraint('value', 'mixed', true),
            new FieldValidationConstraint('warning', 'boolean', true)
        ];
    }
}
