<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Api\Schemas\CustomTexts;
use Kompetenztestde\TestcenterConnector\Api\Schemas\BroadcastingService;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class SystemConfigResponse
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $version;

    /**
     * @var CustomText|null
     */
    private $customTexts;

    /**
     * @var mixed|null
     */
    private $appConfig;

    /**
     * @var BroadcastingService|null
     */
    private $broadcastingService;

    /**
     * @var string|null
     */
    private $baseUrl;

    /**
     * @param object $data
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->version = $data->version;
        $this->customTexts = isset($data->customTexts) ? new CustomTexts($data->customTexts) : null;
        $this->appConfig = $data->appConfig ?? null;
        $this->broadcastingService =
            isset($data->broadcastingService) ? new BroadcastingService($data->broadcastingService) : null;
        $this->baseUrl = $data->baseUrl ?? null;
    }

    /**
     * Get the value of version
     *
     * @return string
     */
    public function getVersion()
    {
        return $this->version;
    }

    /**
     * Set the value of version
     *
     * @param string $version
     * @return self
     */
    public function setVersion(string $version)
    {
        $this->version = $version;

        return $this;
    }

    /**
     * Get the value of customTexts
     *
     * @return string
     */
    public function getCustomTexts()
    {
        return $this->customTexts;
    }

    /**
     * Set the value of customTexts
     *
     * @param string $customTexts
     * @return self
     */
    public function setCustomTexts(string $customTexts)
    {
        $this->customTexts = $customTexts;

        return $this;
    }

    /**
     * Get the value of appConfig
     *
     * @return string
     */
    public function getAppConfig()
    {
        return $this->appConfig;
    }

    /**
     * Set the value of appConfig
     *
     * @param mixed $appConfig
     * @return self
     */
    public function setAppConfig(mixed $appConfig)
    {
        $this->appConfig = $appConfig;

        return $this;
    }

    /**
     * Get the value of baseUrl
     *
     * @return string
     */
    public function getBaseUrl()
    {
        return $this->baseUrl;
    }

    /**
     * Set the value of baseUrl
     *
     * @param string $baseUrl
     * @return self
     */
    public function setBaseUrl(string $baseUrl)
    {
        $this->baseUrl = $baseUrl;

        return $this;
    }

    /**
     * Get the value of broadcastingService
     *
     * @return string
     */
    public function getBroadcastingService()
    {
        return $this->broadcastingService;
    }

    /**
     * Set the value of broadcastingService
     *
     * @param string $broadcastingService
     * @return self
     */
    public function setBroadcastingService(string $broadcastingService)
    {
        $this->broadcastingService = $broadcastingService;

        return $this;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('version', 'string', true)
        ];
    }
}
