<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class UnitResponse
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $groupName;

    /**
     * @var string
     */
    private $loginName;

    /**
     * @var string|null
     */
    private $code;

    /**
     * @var string
     */
    private $bookletName;

    /**
     * @var string
     */
    private $unitName;

    /**
     * @var string|null
     */
    private $lastState;

    /**
     * @var ItemResponse[]|null
     */
    private $responses;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);

        if (isset($data->responses)) {
            $itemResponses = array_map(function ($responseData) {
                return new ItemResponse($responseData);
            }, $data->responses);
        } else {
            $itemResponses = [];
        }

        $this->groupName = $data->groupname;
        $this->loginName = $data->loginname;
        $this->code = $data->code ?? null;
        $this->bookletName = $data->bookletname;
        $this->unitName = $data->unitname;
        $this->lastState = $data->laststate ?? null;
        $this->responses = $itemResponses ?? null;
    }

    /**
     * @return string
     */
    public function getGroupName(): string
    {
        return $this->groupName;
    }

    /**
     * @return string
     */
    public function getLoginName(): string
    {
        return $this->loginName;
    }

    /**
     * @return string
     */
    public function getCode(): string
    {
        return $this->code;
    }

    /**
     * @return string
     */
    public function getBookletName(): string
    {
        return $this->bookletName;
    }

    /**
     * @return string
     */
    public function getUnitName(): string
    {
        return $this->unitName;
    }

    /**
     * @return string
     */
    public function getLastState(): string
    {
        return $this->lastState;
    }

    /**
     * @return ItemResponse[]
     */
    public function getResponses(): array
    {
        return $this->responses;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('groupname', 'string', true),
            new FieldValidationConstraint('loginname', 'string', true),
            new FieldValidationConstraint('code', 'string', false),
            new FieldValidationConstraint('bookletname', 'string', true),
            new FieldValidationConstraint('unitname', 'string', true),
            new FieldValidationConstraint('responses', 'array', false),
            new FieldValidationConstraint('laststate', 'string', false)
        ];
    }
}
