<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

class User
{
    use ValidationTrait;

    /**
     * @var string
     */
    private $name;

    /**
     * @var int
     */
    private $id;

    /**
     * @var string|null
     */
    private $email;

    /**
     * @var bool|null
     */
    private $isSuperadmin;

    /**
     * @var bool|null
     */
    private $selected;

    /**
     * @var string|null
     */
    private $role;

    /**
     * @param object $data api response json object
     * @throws TestcenterConnectorException
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->name = $data->name;
        $this->id = $data->id;
        $this->email = $data->email ?? null;
        $this->isSuperadmin = $data->isSuperadmin ?? null;
        $this->selected = $data->selected ?? null;
        $this->role = $data->role ?? null;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return int|string
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @return string|null
     */
    public function getEmail(): ?string
    {
        return $this->email;
    }

    /**
     * @return bool|null
     */
    public function isSuperadmin(): ?bool
    {
        return $this->isSuperadmin;
    }

    /**
     * @return bool|null
     */
    public function getSelected(): ?bool
    {
        return $this->selected;
    }

    /**
     * @return string|null
     */
    public function getRole(): ?string
    {
        return $this->role;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('name', 'string', true),
            new FieldValidationConstraint('id', 'integer', true),
            new FieldValidationConstraint('email', 'string', false),
            new FieldValidationConstraint('isSuperadmin', 'boolean', false),
            new FieldValidationConstraint('selected', 'boolean', false),
            new FieldValidationConstraint('role', 'string', false)
        ];
    }
}
