<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;

class UserWorkspace
{
    use ValidationTrait;

    /**
     * @var integer
     */
    private $id;

    /**
     * @var string
     */
    private $name;

    /**
     * @var boolean|null
     */
    private $selected;

    /**
     * @var string|null
     */
    private $role;

    /**
     * @param object $data api response json object
     */
    public function __construct(object $data)
    {
        self::validate($data);
        $this->id = $data->id;
        $this->name = $data->name;
        $this->selected = $data->selected ?? null;
        $this->role = $data->role ?? null;
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return bool
     */
    public function isSelected(): bool
    {
        return $this->selected;
    }

    /**
     * @return string
     */
    public function getRole(): string
    {
        return $this->role;
    }

    protected static function getConstraints(): array
    {
        return [
            new FieldValidationConstraint('id', 'integer', true),
            new FieldValidationConstraint('name', 'string', true),
            new FieldValidationConstraint('role', 'string', false),
            new FieldValidationConstraint('selected', 'boolean', false)
        ];
    }
}
