<?php

namespace Kompetenztestde\TestcenterConnector\Api\Schemas;

use Kompetenztestde\TestcenterConnector\Api\FieldValidationConstraint;
use Kompetenztestde\TestcenterConnector\Exceptions\TestcenterConnectorException;

trait ValidationTrait
{
    /**
     * @param object $data
     * @return void
     * @throws TestcenterConnectorException
     */
    protected static function validate(object $data)
    {
        foreach (self::getConstraints() as $constraint) {
            $value = $data->{$constraint->getName()} ?? null;

            if (
                $constraint->isRequired()
                && ($value === null || $value === '')
            ) {
                throw new TestcenterConnectorException('Field "' . $constraint->getName() . '" is missing in response');
            }

            if (
                !$constraint->isRequired()
                && ($value === null || $value === '')
            ) {
                continue;
            }

            $actualType = gettype($value);
            $validation = true;
            switch ($constraint->getType()) {
                case 'integer':
                    if (!is_numeric($value) || (intval($value) != $value)) {
                        $validation = false;
                    }
                    break;
                case 'double':
                    if (!is_numeric($value) || (floatval($value) != $value)) {
                        $validation = false;
                    }
                    break;
                case 'string':
                    if (!is_string($value)) {
                        $validation = false;
                    }
                    break;
                case 'boolean':
                    if (
                        !is_bool($value) && $value !== 'false' && $value !== 'true'
                        && $value !== 0 && $value !== 1
                        && $value !== '0' && $value !== '1'
                    ) {
                        $validation = false;
                    }
                    break;
            }

            if (!$validation) {
                throw new TestcenterConnectorException('Field "' . $constraint->getName()
                    . '" expected to be of type ' . $constraint->getType() . '. Actual: ' . $actualType);
            }
        }
    }

    /**
     * @return FieldValidationConstraint[]
     */
    abstract protected static function getConstraints(): array;
}
