<?php

namespace Kompetenztestde\TestcenterConnector\Models;

use Generator;
use Kompetenztestde\TestcenterConnector\Exceptions\FileNotReadableException;

class FileTest implements TestInterface
{
    /**
     * @var string
     */
    private $bookletPath;

    /**
     * @var string[]
     */
    private $unitPaths;

    /**
     * @var string[]
     */
    private $resourcePaths;

    public function __construct(string $bookletPath, array $unitPaths, array $resourcePaths)
    {
        $this->bookletPath = $bookletPath;
        $this->unitPaths = $unitPaths;
        $this->resourcePaths = $resourcePaths;
    }

    public function getBookletFilename(): string
    {
        return basename($this->bookletPath);
    }

    public function getBookletContent(): string
    {
        if (!is_readable($this->bookletPath) || !is_file($this->bookletPath)) {
            throw new FileNotReadableException($this->bookletPath);
        }
        return file_get_contents($this->bookletPath);
    }

    public function getUnits(): Generator
    {
        foreach ($this->unitPaths as $unitPath) {
            if (!is_readable($unitPath) || !is_file($unitPath)) {
                throw new FileNotReadableException($unitPath);
            }
            yield basename($unitPath) => file_get_contents($unitPath);
        }
    }

    public function getResources(): Generator
    {
        foreach ($this->resourcePaths as $resourcePath) {
            if (!is_readable($resourcePath) || !is_file($resourcePath)) {
                throw new FileNotReadableException($resourcePath);
            }
            yield basename($resourcePath) => file_get_contents($resourcePath);
        }
    }
}
