<?php

namespace Kompetenztestde\TestcenterConnector\Models;

class TestGroup
{
    /**
     * @var string
     */
    private $id;

    /**
     * @var string
     */
    private $label;

    /**
     * @var string|null
     */
    private $password;

    /**
     * @var Login[]
     */
    private $logins;

    /**
     * @var string|null
     */
    private $validFrom;

    /**
     * @var string|null
     */
    private $validTo;

    /**
     * @param string $id
     * @param string $label
     * @param Login[] $logins
     * @param ?string $password
     * @param ?string $validFrom Test start date in format "DD/MM/YYYY HH:MM"
     * @param ?string $validTo Test end date in format "DD/MM/YYYY HH:MM"
     */
    public function __construct(
        string $id,
        string $label,
        array $logins,
        ?string $password = null,
        ?string $validFrom = null,
        ?string $validTo = null
    ) {
        $this->id = $id;
        $this->label = $label;
        $this->logins = $logins;
        $this->password = $password;
        $this->validFrom = $validFrom;
        $this->validTo = $validTo;
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getLabel(): string
    {
        return $this->label;
    }

    /**
     * @return string
     */
    public function getPassword(): ?string
    {
        return $this->password;
    }

    /**
     * @return Login[]
     */
    public function getLogins(): array
    {
        return $this->logins;
    }

    /**
     * @return string|null
     */
    public function getValidFrom(): ?string
    {
        return $this->validFrom;
    }

    /**
     * @return string|null
     */
    public function getValidTo(): ?string
    {
        return $this->validTo;
    }

    /**
     * @return Pupil[]
     */
    public function getPupils(): array
    {
        return array_filter($this->logins, function ($login) {
            return $login instanceof Pupil;
        });
    }

    /**
     * @return Teacher[]
     */
    public function getTeachers(): array
    {
        return array_filter($this->logins, function ($login) {
            return $login instanceof Teacher;
        });
    }
}
