<?php

namespace Kompetenztestde\TestcenterConnector\Xml;

use XMLWriter;

class XmlGenerator
{
    /**
     * Generate a testtakers xml file for a test group
     *
     * @param TestGroup $group group to generate logins for
     * @param string $version testcenter version
     * @return string
     */
    public function generateTesttakersXml(TestGroup $group, string $version): string
    {
        $writer = new XMLWriter();
        $writer->openMemory();

        $writer->startDocument('1.0', 'utf-8');

        $writer->startElement('Testtakers');

        $writer->writeAttributeNs(
            'xsi',
            'noNamespaceSchemaLocation',
            'http://www.w3.org/2001/XMLSchema-instance',
            'https://raw.githubusercontent.com/iqb-berlin/testcenter/' . $version . '/definitions/vo_Testtakers.xsd'
        );

        $writer->startElement('Metadata');
        $writer->writeElement('Description', 'Logins for group ' . $group->getName());
        $writer->endElement(); // Metadata

        $writer->startElement('Group');

        $writer->writeAttribute('id', $group->getId());
        $writer->writeAttribute('label', $group->getName());

        if ($group->getValidFrom() !== null) {
            $writer->writeAttribute('validFrom', $group->getValidFrom());
        }

        if ($group->getValidTo() !== null) {
            $writer->writeAttribute('validTo', $group->getValidTo());
        }

        foreach ($group->getLogins() as $login) {
            $writer->startElement('Login');

            $writer->writeAttribute('name', $login->getName());

            if ($login->getPassword()) {
                $writer->writeAttribute('pw', $login->getPassword());
            }

            $writer->writeAttribute('mode', $login->getMode());

            foreach ($group->getBookletIds() as $bookletId) {
                $writer->writeElement('Booklet', $bookletId);
            }

            $writer->endElement(); // Login
        }

        $writer->endElement(); // Group
        $writer->endElement(); // Testtakers
        $writer->endDocument();

        return $writer->outputMemory();
    }
}
