<?php

namespace Kompetenztestde\TestcenterConnector\Models;

use Kompetenztestde\TestcenterConnector\Exceptions\FileNotReadableException;
use PHPUnit\Framework\TestCase;

class FileTestTest extends TestCase
{
    public function testGetBookletFilename(): void
    {
        $path = 'test/test.xml';
        $filename = 'test.xml';
        $test = new FileTest($path, [], []);

        $this->assertEquals($filename, $test->getBookletFilename());
    }

    public function testGetBookletContent(): void
    {
        $path = 'testAssets/Booklet.xml';
        $content = file_get_contents($path);
        $test = new FileTest($path, [], []);

        $this->assertEquals($content, $test->getBookletContent());
    }

    public function testGetBookletContentNotFound(): void
    {
        $path = 'testAssets/invalid';
        $test = new FileTest($path, [], []);

        $this->expectException(FileNotReadableException::class);
        $test->getBookletContent();
    }

    public function testGetUnits(): void
    {
        $path = 'testAssets/Unit.xml';
        $content = file_get_contents($path);
        $test = new FileTest('', [$path], []);

        $result = iterator_to_array($test->getUnits(), true);

        $this->assertEquals(1, count($result));
        $this->assertTrue(isset($result['Unit.xml']));
        $this->assertEquals($content, $result['Unit.xml']);
    }

    public function testGetUnitsNotFound(): void
    {
        $path = 'testAssets/invalid';
        $test = new FileTest('', [$path], []);

        $this->expectException(FileNotReadableException::class);

        iterator_to_array($test->getUnits());
    }

    public function testGetResources(): void
    {
        $path = 'testAssets/verona-player-simple-4.0.0.html';
        $content = file_get_contents($path);
        $test = new FileTest('', [], [$path]);

        $result = iterator_to_array($test->getResources(), true);

        $this->assertEquals(1, count($result));
        $this->assertTrue(isset($result['verona-player-simple-4.0.0.html']));
        $this->assertEquals($content, $result['verona-player-simple-4.0.0.html']);
    }

    public function testGetResourcesNotFound(): void
    {
        $path = 'testAssets/invalid';
        $test = new FileTest('', [], [$path]);

        $this->expectException(FileNotReadableException::class);

        iterator_to_array($test->getResources());
    }
}