<?php

namespace Kompetenztestde\TestcenterConnector;

use BadMethodCallException;
use PHPUnit\Framework\TestCase;

class MultiTestcenterConnectorTest extends TestCase
{
    public function testCallValidMethod(): void
    {
        $connector1 = $this->createMock(TestcenterConnector::class);
        $connector2 = $this->createMock(TestcenterConnector::class);

        $connector1->expects($this->once())
            ->method('addWorkspace')
            ->with('test-workspace')
            ->willReturn(1);

        $connector2->expects($this->once())
            ->method('addWorkspace')
            ->with('test-workspace')
            ->willReturn(2);

        $connector1->expects($this->any())
            ->method('getBaseUrl')
            ->willReturn('http://testcenter1/api');

        $connector2->expects($this->any())
            ->method('getBaseUrl')
            ->willReturn('http://testcenter2/api');

        $multiConnector = new MultiTestcenterConnector(null, [$connector1, $connector2]);
        $response = $multiConnector->addWorkspace('test-workspace');

        $this->assertCount(2, $response);
        $this->assertEquals(1, $response['http://testcenter1/api']);
        $this->assertEquals(2, $response['http://testcenter2/api']);
    }

    public function testCallInvalidMethod(): void
    {
        $connector1 = $this->createMock(TestcenterConnector::class);
        $connector2 = $this->createMock(TestcenterConnector::class);
        $multiConnector = new MultiTestcenterConnector(null, [$connector1, $connector2]);

        $this->expectException(BadMethodCallException::class);

        $multiConnector->invalidMethod('invalid-param');
    }
}
