<?php

namespace Kompetenztestde\TestcenterConnector\Xml;

use DOMDocument;
use PHPUnit\Framework\TestCase;

class XmlGeneratorTest extends TestCase
{
    public function testGenerateTesttakersXml(): void
    {
        $logins = [
            new TestLogin('login1', 'password1', LoginMode::RUN_HOT_RETURN),
            new TestLogin('login2', 'password2', LoginMode::MONITOR_GROUP)
        ];
        $bookletIds = ['booklet1'];
        $group = new TestGroup('test-group', 'Test Group', $logins, $bookletIds);
        $version = '15.1.4';

        $generator = new XmlGenerator();
        $testtakersXml = $generator->generateTesttakersXml($group, $version);

        // Validate against xsd
        $testtakersDom = new DOMDocument('1.0', 'utf-8');
        $testtakersDom->loadXML($testtakersXml);
        $this->assertTrue($testtakersDom->schemaValidate('testAssets/vo_Testtakers.xsd'));

        // Assert group was generated
        $groupElements = $testtakersDom->getElementsByTagName('Group');
        $this->assertEquals(1, $groupElements->length, '1 group expected');
        $groupElement = $groupElements[0];

        $groupIdAttr = $groupElement->getAttribute('id');
        $this->assertEquals($group->getId(), $groupIdAttr);

        $groupLabelAttr = $groupElement->getAttribute('label');
        $this->assertEquals($group->getName(), $groupLabelAttr);

        // Assert login was generated
        $loginElements = $groupElement->getElementsByTagName('Login');
        $this->assertEquals(count($logins), $loginElements->length, 'Expected ' . count($logins) . ' login elements generated');

        for ($i = 0; $i < count($logins); $i++) {
            $login = $logins[$i];
            $loginElement = $loginElements[$i];

            $nameAttr = $loginElement->getAttribute('name');
            $this->assertEquals($login->getName(), $nameAttr);

            $passwordAttr = $loginElement->getAttribute('pw');
            $this->assertEquals($login->getPassword(), $passwordAttr);

            $modeAttr = $loginElement->getAttribute('mode');
            $this->assertEquals($login->getMode(), $modeAttr);

            $bookletElements = $loginElement->getElementsByTagName('Booklet');
            $this->assertEquals(count($bookletIds), $bookletElements->length);

            for ($j = 0; $j < count($bookletIds); $j++) {
                $bookletId = $bookletIds[$j];
                $bookletElement = $bookletElements[$j];

                $this->assertEquals($bookletId, $bookletElement->textContent);
            }
        }
    }
}